@@ -19,9 +19,8 @@
  * USA
  */
 
-#include <goffice/graph/gog-chart-map-3d.h>
-#include <goffice/graph/gog-3d-box.h>
-#include <goffice/math/go-matrix3x3.h>
+#include <goffice/goffice-config.h>
+#include <goffice/goffice.h>
 
 struct _GogChartMap3D {
 	GogChart 		*chart;
@@ -86,7 +85,7 @@ gog_chart_map_3d_new (GogChart *chart, GogViewAllocation const *area,
 	GogAxisSet axis_set;
 	Gog3DBox *box;
 
-	g_return_val_if_fail (IS_GOG_CHART (chart), NULL);
+	g_return_val_if_fail (GOG_IS_CHART (chart), NULL);
 
 	map = g_new (GogChartMap3D, 1);
 	
@@ -131,10 +130,10 @@ gog_chart_map_3d_new (GogChart *chart, GogViewAllocation const *area,
  * @z: data y value
  * @u: placeholder for x converted value
  * @v: placeholder for y converted value
+ * @w: placeholder for z converted value
  *
  * Converts a 3D coordinate from data space to canvas space.
  **/
-
 void
 gog_chart_map_3d_to_view (GogChartMap3D *map, double x, double y, double z, double *u, double *v, double *w)
 {
