@@ -2,7 +2,7 @@
 /*
  * gog-object.c :
  *
- * Copyright (C) 2003-2004 Jody Goldberg (jody@gnome.org)
+ * Copyright (C) 2003-2007 Jody Goldberg (jody@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -20,195 +20,13 @@
  */
 
 #include <goffice/goffice-config.h>
-#include <goffice/graph/gog-object.h>
-#include <goffice/graph/gog-graph-impl.h> /* for gog_graph_request_update */
-#include <goffice/graph/gog-data-set.h>
-#include <goffice/data/go-data.h>
+#include <goffice/goffice.h>
 
 #include <gsf/gsf-impl-utils.h>
 #include <glib/gi18n-lib.h>
 #include <string.h>
 #include <stdlib.h>
 
-#ifdef GOFFICE_WITH_GTK
-#include <goffice/gtk/goffice-gtk.h>
-#include <gtk/gtkcombobox.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtknotebook.h>
-#include <gtk/gtksizegroup.h>
-#include <gtk/gtkspinbutton.h>
-#include <gtk/gtktogglebutton.h>
-#include <gtk/gtkwidget.h>
-#endif
-
-/*****************************************************************************/
-
-/**
- * gog_editor_new:
- *
- * Creates a new GogEditor object, which is used to store a 
- * collection of property edition widgets (pages). The returned 
- * object must be freed using @gog_editor_free.
- **/
-
-GogEditor *
-gog_editor_new (void)
-{
-	GogEditor *editor = g_new (GogEditor, 1);
-
-	editor->store_page = NULL;
-	editor->pages = NULL;
-	g_datalist_init (&editor->registered_widgets);
-
-	return editor;
-}
-
-/**
- * gog_editor_free:
- * @editor: a #GogEditor
- *
- * Frees a GogEditor object.
- **/
-
-void
-gog_editor_free (GogEditor *editor)
-{
-	g_slist_foreach (editor->pages, (GFunc) g_free, NULL);
-	g_slist_free (editor->pages);
-	g_datalist_clear (&editor->registered_widgets);
-
-	g_free (editor);
-}
-
-/**
- * gog_editor_add_page:
- * @editor: a #GogEditor
- * @widget: property edition widget
- * @label: a label identifying the widget
- *
- * Adds a page to @editor.
- */
-
-void
-gog_editor_add_page (GogEditor *editor, gpointer widget, char const *label)
-{
-	GogEditorPage *page;
-
-	g_return_if_fail (editor != NULL);
-	page = g_new (GogEditorPage, 1);
-
-	page->widget = widget;
-	page->label = label;
-
-	editor->pages = g_slist_prepend (editor->pages, page);
-}
-
-/**
- * gog_editor_set_store_page:
- * @editor: a #GogEditor
- * @store_page: placeholder for the last selected page
- *
- * Sets a placeholder for storing the last active editor page.
- **/
-
-void
-gog_editor_set_store_page (GogEditor *editor, unsigned *store_page)
-{
-	g_return_if_fail (editor != NULL);
-
-	editor->store_page = store_page;
-}
-
-#ifdef GOFFICE_WITH_GTK
-
-/**
- * gog_editor_register_widget:
- * @editor: a #GogEditor
- * @widget: a #GtkWidget
- * 
- * Registers a widget that then can be retrieved later using 
- * @gog_editor_get_registered_widget. The main use of this function is to 
- * provide the ability to extend a page.
- **/
-
-void
-gog_editor_register_widget (GogEditor *editor, GtkWidget *widget)
-{
-	g_return_if_fail (editor != NULL);
-	g_return_if_fail (GTK_IS_WIDGET (widget));
-
-	g_datalist_set_data (&editor->registered_widgets, gtk_widget_get_name (widget), widget);
-}
-
-/**
- * gog_editor_get_registered_widget:
- * @editor: a #GogEditor
- * @name: the name of the registered widget
- *
- * Retrieves a widget previously registered using @gog_editor_register_widget.
- **/
-
-GtkWidget *
-gog_editor_get_registered_widget (GogEditor *editor, char const *name)
-{
-	g_return_val_if_fail (editor != NULL, NULL);
-
-	return g_datalist_get_data (&editor->registered_widgets, name);
-}
-
-static void
-cb_switch_page (G_GNUC_UNUSED GtkNotebook *n, G_GNUC_UNUSED GtkNotebookPage *p,
-		guint page_num, guint *store_page)
-{
-		*store_page = page_num;
-}
-
-/**
- * gog_editor_get_notebook:
- * @editor: a #GogEditor
- *
- * Buils a GtkNotebook from the widget collection stored in @editor.
- **/
-
-GtkWidget *
-gog_editor_get_notebook (GogEditor *editor)
-{
-	GtkWidget *notebook;
-	GogEditorPage *page;
-	GSList *ptr;
-	unsigned page_count = 0;
-
-	notebook = gtk_notebook_new ();
-	if (editor->pages != NULL) {
-		for (ptr = editor->pages; ptr != NULL; ptr = ptr->next) {
-			page = (GogEditorPage *) ptr->data;
-			gtk_notebook_prepend_page (GTK_NOTEBOOK (notebook),
-						   GTK_WIDGET (page->widget),
-						   gtk_label_new (page->label));
-			gtk_widget_show (page->widget);
-			page_count ++;
-		}
-	} else {
-		/* Display a blank page */
-		GtkWidget *label =  gtk_label_new (NULL);
-		gtk_notebook_prepend_page (GTK_NOTEBOOK (notebook),
-					   label, NULL);
-		gtk_widget_show (label);
-		page_count = 1;
-	}
-
-	if (editor->store_page != NULL) {
-		gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), *editor->store_page);
-		g_signal_connect (G_OBJECT (notebook),
-				  "switch_page",
-				  G_CALLBACK (cb_switch_page), editor->store_page);
-	} else
-		gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), 0);
-
-	return notebook;
-}
-
-#endif
 
 typedef struct {
 	char const *label;
@@ -254,6 +72,7 @@ enum {
 	OBJECT_PROP_POSITION_ALIGNMENT,
 	OBJECT_PROP_POSITION_IS_MANUAL,
 	OBJECT_PROP_POSITION_ANCHOR,
+	OBJECT_PROP_INVISIBLE,
 };
 
 enum {
@@ -296,7 +115,7 @@ gog_object_parent_changed (GogObject *child, gboolean was_set)
 		(*klass->parent_changed) (ptr->data, was_set);
 	}
 
-	if (IS_GOG_DATASET (child))
+	if (GOG_IS_DATASET (child))
 		gog_dataset_parent_changed (GOG_DATASET (child), was_set);
 }
 
@@ -368,6 +187,9 @@ gog_object_set_property (GObject *obj, guint param_id,
 						       position_anchor[id].flags, 
 						       GOG_POSITION_ANCHOR);
 		break;
+	case OBJECT_PROP_INVISIBLE :
+		gog_object_set_invisible (gobj, g_value_get_boolean (value));
+		break;
 
 	default: G_OBJECT_WARN_INVALID_PROPERTY_ID (obj, param_id, pspec);
 		 return; /* NOTE : RETURN */
@@ -427,6 +249,9 @@ gog_object_get_property (GObject *obj, guint param_id,
 				break;
 			}
 		break;
+	case OBJECT_PROP_INVISIBLE :
+		g_value_set_boolean (value, gobj->invisible != 0);
+		break;
 
 	default: G_OBJECT_WARN_INVALID_PROPERTY_ID (obj, param_id, pspec);
 		 break;
@@ -533,7 +358,7 @@ cb_update_editor (GogObject *gobj, ObjectPrefState *state)
 
 static void
 gog_object_populate_editor (GogObject *gobj, 
-			    GogEditor *editor, 
+			    GOEditor *editor, 
 			    G_GNUC_UNUSED GogDataAllocator *dalloc, 
 			    GOCmdContext *cc)
 {
@@ -554,7 +379,7 @@ gog_object_populate_editor (GogObject *gobj,
 	if (!(allowable_positions & (GOG_POSITION_MANUAL | GOG_POSITION_COMPASS)))
 		return;	
 
-	gui = go_libglade_new ("gog-object-prefs.glade", "gog_object_prefs", GETTEXT_PACKAGE, cc);
+	gui = go_glade_new ("gog-object-prefs.glade", "gog_object_prefs", GETTEXT_PACKAGE, cc);
 	if (gui == NULL)
 		return;
 
@@ -695,7 +520,7 @@ gog_object_populate_editor (GogObject *gobj,
 	w = glade_xml_get_widget (gui, "gog_object_prefs");
 	g_object_set_data_full (G_OBJECT (w), "state", state, 
 				(GDestroyNotify) object_pref_state_free);  
-	gog_editor_add_page (editor, w, _("Position"));
+	go_editor_add_page (editor, w, _("Position"));
 }
 #endif
 
@@ -737,38 +562,52 @@ gog_object_class_init (GObjectClass *klass)
 			_("Object ID"), 
 			_("Object numerical ID"),
 			0, G_MAXINT, 0,
-			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 	g_object_class_install_property (klass, OBJECT_PROP_POSITION,
 		g_param_spec_string ("position", 
 			_("Position"), 
 			_("Position and size of object, in percentage of parent size"),
 			"0 0 1 1", 
-			GSF_PARAM_STATIC | G_PARAM_READWRITE|GOG_PARAM_PERSISTENT));
+			GSF_PARAM_STATIC | G_PARAM_READWRITE|GO_PARAM_PERSISTENT));
 	g_object_class_install_property (klass, OBJECT_PROP_POSITION_COMPASS,
 		g_param_spec_string ("compass", 
 			_("Compass"),
 			_("Compass auto position flags"),
 			"top", 
-			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT | GOG_PARAM_POSITION));
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT | GOG_PARAM_POSITION));
 	g_object_class_install_property (klass, OBJECT_PROP_POSITION_ALIGNMENT,
 		g_param_spec_string ("alignment", 
 			_("Alignment"),
 			_("Alignment flag"),
 			"fill",
-		       	GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT | GOG_PARAM_POSITION));
+		       	GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT | GOG_PARAM_POSITION));
 	g_object_class_install_property (klass, OBJECT_PROP_POSITION_IS_MANUAL,
 		g_param_spec_boolean ("is-position-manual", 
 			_("Is position manual"), 
 			_("Is position manual"),
 			FALSE, 
-			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 	g_object_class_install_property (klass, OBJECT_PROP_POSITION_ANCHOR,
 		g_param_spec_string ("anchor", 
 			_("Anchor"),
 			_("Anchor for manual position"),
 			"top-left", 
-			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT | GOG_PARAM_POSITION));
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT | GOG_PARAM_POSITION));
+	g_object_class_install_property (klass, OBJECT_PROP_INVISIBLE,
+		g_param_spec_boolean ("invisible", 
+			_("Should the object be hidden"), 
+			_("Should the object be hidden"),
+			FALSE, 
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 
+	/**
+	 * GogObject::child-added:
+	 * @object: the object on which the signal is emitted
+	 * @child: The new #GogObject whose parent is @object
+	 *
+	 * The ::child-added signal is emitted AFTER the child has been added
+	 * and AFTER the parent-changed signal has been called for it.
+	 **/
 	gog_object_signals [CHILD_ADDED] = g_signal_new ("child-added",
 		G_TYPE_FROM_CLASS (klass),
 		G_SIGNAL_RUN_LAST,
@@ -776,6 +615,14 @@ gog_object_class_init (GObjectClass *klass)
 		NULL, NULL,
 		g_cclosure_marshal_VOID__OBJECT,
 		G_TYPE_NONE,	1, G_TYPE_OBJECT);
+	/**
+	 * GogObject::child-removed:
+	 * @object: the object on which the signal is emitted
+	 * @child: The new #GogObject whose parent is @object
+	 *
+	 * The ::child-removed signal is emitted BEFORE the child has been
+	 * added and BEFORE the parent-changed signal has been called for it.
+	 **/
 	gog_object_signals [CHILD_REMOVED] = g_signal_new ("child-removed",
 		G_TYPE_FROM_CLASS (klass),
 		G_SIGNAL_RUN_LAST,
@@ -829,6 +676,8 @@ gog_object_init (GogObject *obj)
 	obj->id = 0;
 	obj->needs_update = FALSE;
 	obj->being_updated = FALSE;
+	obj->explicitly_typed_role = FALSE;
+	obj->invisible = FALSE;
 	obj->manual_position.x =
 	obj->manual_position.y = 0.0;
 	obj->manual_position.w =
@@ -891,8 +740,8 @@ gog_object_generate_name (GogObject *obj)
 unsigned
 gog_object_get_id (GogObject const *obj)
 {
-	g_return_val_if_fail (IS_GOG_OBJECT (obj), 0);
-	g_return_val_if_fail (obj != 0, 0);
+	g_return_val_if_fail (GOG_IS_OBJECT (obj), 0);
+	g_return_val_if_fail (obj != NULL, 0);
 
 	return obj->id;
 }
@@ -926,7 +775,7 @@ gog_object_set_id (GogObject *obj, unsigned id)
 	GSList *ptr;
 	GogObject *child;
 
-	g_return_if_fail (IS_GOG_OBJECT (obj));
+	g_return_if_fail (GOG_IS_OBJECT (obj));
 
 	if (id == 0) {
 		gog_object_generate_id (obj);
@@ -976,7 +825,6 @@ dataset_dup (GogDataset const *src, GogDataset *dst)
  *
  * Returns: FIXME
  **/
-
 GogObject *
 gog_object_dup (GogObject const *src, GogObject *new_parent, GogDataDuplicator datadup)
 {
@@ -996,11 +844,13 @@ gog_object_dup (GogObject const *src, GogObject *new_parent, GogDataDuplicator d
 	if (new_parent)
 		dst = gog_object_add_by_role (new_parent, src->role, dst);
 
+	g_return_val_if_fail (GOG_OBJECT (dst) != NULL, NULL);
+
 	dst->position = src->position;
 	/* properties */
 	props = g_object_class_list_properties (G_OBJECT_GET_CLASS (src), &n);
 	while (n-- > 0)
-		if (props[n]->flags & GOG_PARAM_PERSISTENT) {
+		if (props[n]->flags & GO_PARAM_PERSISTENT) {
 			g_value_init (&val, props[n]->value_type);
 			g_object_get_property (G_OBJECT (src), props[n]->name, &val);
 			g_object_set_property (G_OBJECT (dst), props[n]->name, &val);
@@ -1008,7 +858,7 @@ gog_object_dup (GogObject const *src, GogObject *new_parent, GogDataDuplicator d
 		}
 	g_free (props);
 
-	if (IS_GOG_DATASET (src)) {	/* convenience to save data */
+	if (GOG_IS_DATASET (src)) {	/* convenience to save data */
 		if (datadup)
 			datadup (GOG_DATASET (src), GOG_DATASET (dst));
 		else
@@ -1027,13 +877,13 @@ gog_object_dup (GogObject const *src, GogObject *new_parent, GogDataDuplicator d
  * gog_object_get_parent :
  * @obj : a #GogObject
  *
- * Returns: @obj's parent, potentially NULL if it has not been added to a
- * heirarchy yet.  does not change ref-count in any way.
+ * Returns: @obj's parent, potentially %NULL if it has not been added to a
+ * 	heirarchy yet.  does not change ref-count in any way.
  **/
 GogObject *
 gog_object_get_parent (GogObject const *obj)
 {
-	g_return_val_if_fail (IS_GOG_OBJECT (obj), NULL);
+	g_return_val_if_fail (GOG_IS_OBJECT (obj), NULL);
 	return obj->parent;
 }
 
@@ -1042,13 +892,13 @@ gog_object_get_parent (GogObject const *obj)
  * @obj: a #GogObject
  * @t: a #GType
  *
- * Returns: @obj's parent of type @type, potentially NULL if it has not been
+ * Returns: @obj's parent of type @type, potentially %NULL if it has not been
  * added to a hierarchy yet or none of the parents are of type @type.
  **/
 GogObject *
 gog_object_get_parent_typed (GogObject const *obj, GType t)
 {
-	g_return_val_if_fail (IS_GOG_OBJECT (obj), NULL);
+	g_return_val_if_fail (GOG_IS_OBJECT (obj), NULL);
 
 	for (; obj != NULL ; obj = obj->parent)
 		if (G_TYPE_CHECK_INSTANCE_TYPE (obj, t))
@@ -1065,10 +915,10 @@ gog_object_get_parent_typed (GogObject const *obj, GType t)
 GogGraph *
 gog_object_get_graph (GogObject const *obj)
 {
-	g_return_val_if_fail (IS_GOG_OBJECT (obj), NULL);
+	g_return_val_if_fail (GOG_IS_OBJECT (obj), NULL);
 
 	for (; obj != NULL ; obj = obj->parent)
-		if (IS_GOG_GRAPH (obj))
+		if (GOG_IS_GRAPH (obj))
 			return GOG_GRAPH (obj);
 	return NULL;
 }
@@ -1086,30 +936,32 @@ gog_object_get_theme (GogObject const *obj)
  * @obj : a #GogObject
  *
  * No need to free the result
+ *
+ * Returns: a name.
  **/
 char const *
 gog_object_get_name (GogObject const *obj)
 {
-	g_return_val_if_fail (IS_GOG_OBJECT (obj), NULL);
+	g_return_val_if_fail (GOG_IS_OBJECT (obj), NULL);
 	return (obj->user_name != NULL && *obj->user_name != '\0') ? obj->user_name : obj->auto_name;
 }
 
 /**
  * gog_object_set_name :
  * @obj : #GogObject
- * @name :
+ * @name : The new name for @obj
  * @err : #GError
  *
  * Assign the new name and signals that it has changed.
  * NOTE : it _absorbs_ @name rather than copying it, and generates a new name
- * if @name == NULL
+ * if @name == %NULL
  **/
 void
 gog_object_set_name (GogObject *obj, char *name, GError **err)
 {
 	GogObject *tmp;
 
-	g_return_if_fail (IS_GOG_OBJECT (obj));
+	g_return_if_fail (GOG_IS_OBJECT (obj));
 
 	if (obj->user_name == name)
 		return;
@@ -1129,14 +981,15 @@ gog_object_set_name (GogObject *obj, char *name, GError **err)
  * @obj : a #GogObject
  * @filter : an optional #GogObjectRole to use as a filter
  *
- * The list needs to be Freed
+ * Returns: A list of @obj's Children.  Caller must free the list, but not the
+ * 		children.
  **/
 GSList *
 gog_object_get_children (GogObject const *obj, GogObjectRole const *filter)
 {
 	GSList *ptr, *res = NULL;
 
-	g_return_val_if_fail (IS_GOG_OBJECT (obj), NULL);
+	g_return_val_if_fail (GOG_IS_OBJECT (obj), NULL);
 
 	if (filter == NULL)
 		return g_slist_copy (obj->children);
@@ -1152,9 +1005,9 @@ gog_object_get_children (GogObject const *obj, GogObjectRole const *filter)
  * @obj : a #GogObject
  * @role : a #GogObjectRole to use as a filter
  *
- * A convenience routine to handle a unique child
+ * A convenience routine to find a unique child with @role.
  *
- * Returns: NULL and spews an error if there is more than one.
+ * Returns: %NULL and spews an error if there is more than one.
  **/
 GogObject *
 gog_object_get_child_by_role (GogObject const *obj, GogObjectRole const *role)
@@ -1172,10 +1025,11 @@ gog_object_get_child_by_role (GogObject const *obj, GogObjectRole const *role)
  *
  * gog_object_get_child_by_name :
  * @obj : a #GogObject
- * @role : a #char to use as a filter
+ * @name : a #char to use as a role name filter
  *
- * A convenience routine to handle a unique child
- * Returns NULL and spews an error if there is more than one.
+ * A convenience routine to find a unique child with role == @name
+ *
+ * Returns: %NULL and spews an error if there is more than one.
  **/
 GogObject *
 gog_object_get_child_by_name (GogObject const *obj, char const *name)
@@ -1188,14 +1042,14 @@ gog_object_get_child_by_name (GogObject const *obj, char const *name)
  * gog_object_is_deletable :
  * @obj : a #GogObject
  *
- * Can the specified @obj be deleted ?
+ * Returns: %TRUE if @obj can be deleted.
  **/
 gboolean
 gog_object_is_deletable (GogObject const *obj)
 {
-	g_return_val_if_fail (IS_GOG_OBJECT (obj), FALSE);
+	g_return_val_if_fail (GOG_IS_OBJECT (obj), FALSE);
 
-	if (IS_GOG_GRAPH (obj))
+	if (GOG_IS_GRAPH (obj))
 		return FALSE;
 
 	return obj->role == NULL || obj->role->can_remove == NULL ||
@@ -1257,7 +1111,7 @@ gog_role_cmp_full (GogObjectRole const *a, GogObjectRole const *b)
  * @parent: a #GogObject
  *
  * Returns: a list of GogObjectRoles that could be added.
- * The resulting list needs to be freed
+ * 	The resulting list needs to be freed
  **/
 GSList *
 gog_object_possible_additions (GogObject const *parent)
@@ -1282,8 +1136,8 @@ gog_object_possible_additions (GogObject const *parent)
 /**
  * gog_object_can_reorder :
  * @obj : #GogObject
- * @inc_ok : possibly NULL pointer.
- * @dec_ok : possibly NULL pointer.
+ * @inc_ok : optionally %NULL pointer for result.
+ * @dec_ok : optionally %NULL pointer for result.
  *
  * If @obj can move forward or backward in its parents child list
  **/
@@ -1293,7 +1147,7 @@ gog_object_can_reorder (GogObject const *obj, gboolean *inc_ok, gboolean *dec_ok
 	GogObject const *parent;
 	GSList *ptr;
 
-	g_return_if_fail (IS_GOG_OBJECT (obj));
+	g_return_if_fail (GOG_IS_OBJECT (obj));
 
 	if (inc_ok != NULL)
 		*inc_ok = FALSE;
@@ -1341,7 +1195,7 @@ gog_object_reorder (GogObject const *obj, gboolean inc, gboolean goto_max)
 	GogObject *parent, *obj_follows;
 	GSList **ptr, *tmp;
 
-	g_return_val_if_fail (IS_GOG_OBJECT (obj), NULL);
+	g_return_val_if_fail (GOG_IS_OBJECT (obj), NULL);
 
 	if (obj->parent == NULL || gog_object_get_graph (obj) == NULL)
 		return NULL;
@@ -1380,7 +1234,7 @@ gog_object_reorder (GogObject const *obj, gboolean inc, gboolean goto_max)
 	/* Pass the sibling that precedes obj, or NULL if is the head */
 	g_signal_emit (G_OBJECT (parent),
 		gog_object_signals [CHILDREN_REORDERED], 0);
-	gog_object_emit_changed (parent, TRUE);
+	gog_object_emit_changed (parent, FALSE);
 
 	return obj_follows;
 }
@@ -1394,7 +1248,7 @@ gog_object_reorder (GogObject const *obj, gboolean inc, gboolean goto_max)
  * Builds an object property editor, by calling GogObject::populate_editor
  * virtual functions.
  * 
- * return value: a #GtkNotebook widget
+ * Returns: a #GtkNotebook widget
  **/
 gpointer
 gog_object_get_editor (GogObject *obj, GogDataAllocator *dalloc,
@@ -1402,12 +1256,12 @@ gog_object_get_editor (GogObject *obj, GogDataAllocator *dalloc,
 {
 #ifdef GOFFICE_WITH_GTK
 	GtkWidget *notebook;
-	GogEditor *editor;
+	GOEditor *editor;
 	GogObjectClass *klass = GOG_OBJECT_GET_CLASS (obj);
 
 	g_return_val_if_fail (klass != NULL, NULL);
 
-	editor = gog_editor_new ();
+	editor = go_editor_new ();
 	if (klass->populate_editor) {
 		/* If there are pending updates do them before creating the editor
 		 * to avoid expensive widget changes later */
@@ -1415,9 +1269,9 @@ gog_object_get_editor (GogObject *obj, GogDataAllocator *dalloc,
 		(*klass->populate_editor) (obj, editor, dalloc, cc);
 	}
 
-	notebook = gog_editor_get_notebook (editor);
+	notebook = go_editor_get_notebook (editor);
 
-	gog_editor_free (editor);
+	go_editor_free (editor);
 
 	return notebook;
 #else
@@ -1505,7 +1359,7 @@ gog_object_emit_changed (GogObject *obj, gboolean resize)
 	if (gog_klass->use_parent_as_proxy) {
 		obj = obj->parent;
 		if (obj != NULL) {
-			g_return_if_fail (IS_GOG_OBJECT (obj));
+			g_return_if_fail (GOG_IS_OBJECT (obj));
 			gog_object_emit_changed (obj, resize);
 		}
 		return;
@@ -1536,6 +1390,8 @@ gog_object_request_editor_update (GogObject *obj)
  *
  * Does _not_ unref the child, which in effect adds a ref by freeing up the ref
  * previously associated with the parent.
+ *
+ * Returns: %TRUE on success.
  **/
 gboolean
 gog_object_clear_parent (GogObject *obj)
@@ -1575,6 +1431,8 @@ gog_object_clear_parent (GogObject *obj)
  * @role: a static string that can be sent to @parent::add
  *
  * Absorbs a ref to @child
+ *
+ * Returns: %TRUE on success
  **/
 gboolean
 gog_object_set_parent (GogObject *child, GogObject *parent,
@@ -1614,6 +1472,16 @@ gog_object_set_parent (GogObject *child, GogObject *parent,
 	return TRUE;
 }
 
+/**
+ * gog_object_add_by_role :
+ * @parent : #GogObject
+ * @role : #GogObjectRole
+ * @child : #GogObject
+ *
+ * Absorb a ref to @child if it is non-NULL.
+ * Returns: @child or a newly created object with @role.  Callers do _not_ own
+ * 	the reference.
+ **/
 GogObject *
 gog_object_add_by_role (GogObject *parent, GogObjectRole const *role, GogObject *child)
 {
@@ -1661,22 +1529,37 @@ GogObject *
 gog_object_add_by_name (GogObject *parent,
 			char const *role, GogObject *child)
 {
-	g_return_val_if_fail (IS_GOG_OBJECT (parent), NULL);
+	g_return_val_if_fail (GOG_IS_OBJECT (parent), NULL);
 	return gog_object_add_by_role (parent,
 		gog_object_find_role_by_name (parent, role), child);
 }
 
+/**
+ * gog_object_set_invisible :
+ * @obj : #GogObject
+ * @invisible :
+ **/
+void
+gog_object_set_invisible (GogObject *obj, gboolean invisible)
+{
+	unsigned int new_val = invisible ? 1 : 0;
+	if ((!obj->invisible) != !(new_val)) {
+		obj->invisible = new_val;
+		gog_object_emit_changed (obj, TRUE);
+	}
+}
+
 /**
  * gog_object_get_position_flags :
  * @obj : #GogObject
  * @mask : #GogObjectPosition
  *
- * Retrieve position flags of GogObject @obj, masked by @mask.
- */
+ * Returns: @obj's position flags, masked by @mask.
+ **/
 GogObjectPosition
 gog_object_get_position_flags (GogObject const *obj, GogObjectPosition mask)
 {
-	g_return_val_if_fail (IS_GOG_OBJECT (obj), GOG_POSITION_SPECIAL & mask);
+	g_return_val_if_fail (GOG_IS_OBJECT (obj), GOG_POSITION_SPECIAL & mask);
 	return obj->position & mask;
 }
 
@@ -1693,7 +1576,7 @@ gog_object_get_position_flags (GogObject const *obj, GogObjectPosition mask)
 gboolean
 gog_object_set_position_flags (GogObject *obj, GogObjectPosition flags, GogObjectPosition mask)
 {
-	g_return_val_if_fail (IS_GOG_OBJECT (obj), FALSE);
+	g_return_val_if_fail (GOG_IS_OBJECT (obj), FALSE);
 
 	if (obj->role == NULL)
 		return FALSE;
@@ -1870,9 +1753,17 @@ gog_object_allocate_roles (GogObjectClass *klass)
 	klass->roles_allocated = TRUE;
 }
 
+/**
+ * gog_object_register_roles :
+ * @klass: #GogObjectClass
+ * @roles: #GogObjectRole
+ * @n_roles: number of roles
+ *
+ **/
+
 void
 gog_object_register_roles (GogObjectClass *klass,
-			   GogObjectRole const *roles, unsigned n_roles)
+			   GogObjectRole const *roles, unsigned int n_roles)
 {
 	unsigned i;
 
@@ -1886,3 +1777,13 @@ gog_object_register_roles (GogObjectClass *klass,
 			(gpointer )roles[i].id, (gpointer) (roles + i));
 	}
 }
+
+void
+gog_object_document_changed (GogObject *obj, GODoc *doc)
+{
+	GSList *ptr;
+	if (GOG_OBJECT_GET_CLASS (obj)->document_changed != NULL)
+		GOG_OBJECT_GET_CLASS (obj)->document_changed (obj, doc);
+	for (ptr = obj->children; ptr != NULL; ptr = ptr->next)
+		gog_object_document_changed (GOG_OBJECT (ptr->data), doc);
+}
