@@ -55,7 +55,7 @@ gog_contour_plot_build_matrix (GogXYZPlot const *plot, gboolean *cardinality_cha
 	unsigned nticks;
 	double *x, val;
 	GogSeries *series = GOG_SERIES (plot->base.series->data);
-	GODataMatrix *mat = GO_DATA_MATRIX (series->values[2].data);
+	GOData *mat = series->values[2].data;
 	unsigned n = plot->rows * plot->columns;
 	double *data, minimum, maximum, slope, offset = 0.;
 	unsigned max;
@@ -93,7 +93,7 @@ gog_contour_plot_build_matrix (GogXYZPlot const *plot, gboolean *cardinality_cha
 	for (i = 0; i < plot->rows; i++)
 		for (j = 0; j < plot->columns; j++) {
 			val = gog_axis_map_to_view (map,
-					go_data_matrix_get_value (mat, i, j));
+					go_data_get_matrix_value (mat, i, j));
 			if (fabs (val) == DBL_MAX)
 				val = go_nan;
 			else {
@@ -112,6 +112,11 @@ gog_contour_plot_build_matrix (GogXYZPlot const *plot, gboolean *cardinality_cha
 	}
 	gog_axis_map_free (map);
 	g_free (x);
+	if (max < 2) { /* this might happen with bad 3d axis configuration */
+		g_free (data);
+		return NULL;
+	}
+
 	return data;
 }
 
@@ -129,21 +134,17 @@ gog_contour_plot_foreach_elem  (GogPlot *plot, gboolean only_visible,
 {
 	unsigned i, j, nticks;
 	char *label;
-	static char separator = 0;
-	GogStyle *style = gog_style_new ();
+	GOStyle *style = go_style_new ();
 	GogTheme *theme = gog_object_get_theme (GOG_OBJECT (plot));
 	GogAxis *axis = plot->axis[GOG_AXIS_PSEUDO_3D];
 	GOColor *color;
 	GogAxisTick *zticks;
 	double *limits;
 	double minimum, maximum;
+	char const *separator = go_locale_get_decimal ()->str;
 
 	gog_axis_get_bounds (axis, &minimum, &maximum);
 
-	if (separator == 0) {
-		struct lconv *lc = localeconv ();
-		separator = (strcmp (lc->decimal_point, ","))? ',': ';';
-	}
 	nticks = gog_axis_get_ticks (axis, &zticks);
 	limits = g_new (double, nticks + 1);
 	for (i = j = 0; i < nticks; i++)
@@ -162,23 +163,23 @@ gog_contour_plot_foreach_elem  (GogPlot *plot, gboolean only_visible,
 	}
 	g_object_unref (style);
 
-	style = gog_style_new ();
-	style->interesting_fields = GOG_STYLE_FILL;
-	style->disable_theming = GOG_STYLE_ALL;
-	style->fill.type = GOG_FILL_STYLE_PATTERN;
+	style = go_style_new ();
+	style->interesting_fields = GO_STYLE_FILL;
+	style->disable_theming = GO_STYLE_ALL;
+	style->fill.type = GO_STYLE_FILL_PATTERN;
 	style->fill.pattern.pattern = GO_PATTERN_SOLID;
 
 	if (gog_axis_is_inverted (axis)) {
 		for (i = 0; i < j; i++) {
 			style->fill.pattern.back = color[i];
-			label = g_strdup_printf ("[%g%c %g%c", limits[j - i - 1], separator,
+			label = g_strdup_printf ("[%g%s %g%c", limits[j - i - 1], separator,
 						limits[j - i], (limits[i - j] > minimum)? '[':']');
 			(func) (i, style, label, data);
 			g_free (label);
 		}
 		if (limits[i - j] > minimum) {
 			gog_theme_fillin_style (theme, style, GOG_OBJECT (plot->series->data), i, FALSE);
-			label = g_strdup_printf ("[%g%c %g]", minimum, separator,
+			label = g_strdup_printf ("[%g%s %g]", minimum, separator,
 						limits[i - j]);
 			(func) (i, style, label, data);
 			g_free (label);
@@ -186,7 +187,7 @@ gog_contour_plot_foreach_elem  (GogPlot *plot, gboolean only_visible,
 	} else {
 		if (minimum < limits[0]) {
 			style->fill.pattern.back = color[0];
-			label = g_strdup_printf ("[%g%c %g]", minimum, separator,
+			label = g_strdup_printf ("[%g%s %g]", minimum, separator,
 						limits[0]);
 			(func) (0, style, label, data);
 			g_free (label);
@@ -196,7 +197,7 @@ gog_contour_plot_foreach_elem  (GogPlot *plot, gboolean only_visible,
 			i = 0;
 		for (; i < j; i++) {
 			style->fill.pattern.back = color[i];
-			label = g_strdup_printf ("[%g%c %g%c", limits[i], separator,
+			label = g_strdup_printf ("[%g%s %g%c", limits[i], separator,
 						limits[i + 1], (i == j - 1)? ']':'[');
 			(func) (i, style, label, data);
 			g_free (label);
@@ -231,11 +232,12 @@ gog_contour_plot_init (GogContourPlot *contour)
 	GogPlot *plot = GOG_PLOT (contour);
 
 	plot->render_before_axes = TRUE;
+	plot->vary_style_by_element = TRUE;
 }
 
 GSF_DYNAMIC_CLASS (GogContourPlot, gog_contour_plot,
 	gog_contour_plot_class_init, gog_contour_plot_init,
-	GOG_XYZ_PLOT_TYPE)
+	GOG_TYPE_XYZ_PLOT)
 
 /*****************************************************************************/
 
@@ -248,7 +250,7 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 {
 	GogXYZPlot const *plot = GOG_XYZ_PLOT (view->model);
 	GogSeries const *series;
-	GODataVector *x_vec = NULL, *y_vec = NULL;
+	GOData *x_vec = NULL, *y_vec = NULL;
 	GogAxisMap *x_map, *y_map;
 	double zval0, zval1, zval2 = 0., zval3, t;
 	double x[4], y[4], zval[4];
@@ -257,7 +259,7 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 	int k, kmax, r = 0, s, h;
 	unsigned i, imax, j, jmax;
 	GogRenderer *rend = view->renderer;
-	GogStyle *style;
+	GOStyle *style;
 	GogTheme *theme = gog_object_get_theme (GOG_OBJECT (plot));
 	double x0, x1, y0, y1;
 	GOPath *path, *lines;
@@ -281,6 +283,13 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 	if (imax ==0 || jmax == 0)
 		return;
 
+	if (plot->plotted_data)
+		data = plot->plotted_data;
+	else
+		data = gog_xyz_plot_build_matrix (plot, &cw);
+	if (data == NULL)
+		return;
+
 	x_map = gog_axis_map_new (plot->base.axis[0], 
 				  view->residual.x , view->residual.w);
 	y_map = gog_axis_map_new (plot->base.axis[1], 
@@ -294,36 +303,32 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 		return;
 	}
 
-	if (plot->plotted_data)
-		data = plot->plotted_data;
-	else
-		data = gog_xyz_plot_build_matrix (plot, &cw);
-
 	/* Set cw to ensure that polygons will allways be drawn clockwise */
 	xdiscrete = gog_axis_is_discrete (plot->base.axis[0]) ||
 			series->values[(plot->transposed)? 1: 0].data == NULL;
 	if (xdiscrete) {
 		x0 = gog_axis_map_to_view (x_map, 0.);
 		x1 = gog_axis_map_to_view (x_map, 1.);
-	}else {
-		x_vec = GO_DATA_VECTOR (series->values[(plot->transposed)? 1: 0].data);
-		x0 = gog_axis_map_to_view (x_map, go_data_vector_get_value (x_vec, 0));
-		x1 = gog_axis_map_to_view (x_map, go_data_vector_get_value (x_vec, 1));
+	} else {
+		x_vec = gog_xyz_plot_get_x_vals (GOG_XYZ_PLOT (plot));
+		x0 = gog_axis_map_to_view (x_map, go_data_get_vector_value (x_vec, 0));
+		x1 = gog_axis_map_to_view (x_map, go_data_get_vector_value (x_vec, 1));
 	}
 	ydiscrete = gog_axis_is_discrete (plot->base.axis[1]) ||
 			series->values[(plot->transposed)? 0: 1].data == NULL;
 	if (ydiscrete) {
 		y0 = gog_axis_map_to_view (y_map, 0.);
 		y1 = gog_axis_map_to_view (y_map, 1.);
-	}else {
-		y_vec = GO_DATA_VECTOR (series->values[(plot->transposed)? 0: 1].data);
-		y0 = gog_axis_map_to_view (y_map, go_data_vector_get_value (y_vec, 0));
-		y1 = gog_axis_map_to_view (y_map, go_data_vector_get_value (y_vec, 1));
+	} else {
+		y_vec = gog_xyz_plot_get_y_vals (GOG_XYZ_PLOT (plot));
+		y0 = gog_axis_map_to_view (y_map, go_data_get_vector_value (y_vec, 0));
+		y1 = gog_axis_map_to_view (y_map, go_data_get_vector_value (y_vec, 1));
 	}
 	cw = (x1 > x0) == (y1 > y0);
 
-	style = gog_style_new ();
+	style = go_style_new ();
 	path = go_path_new ();
+	go_path_set_options (path, GO_PATH_OPTIONS_SHARP);
 	/* build the colors table */
 	color = g_new0 (GOColor, max);
 	if (max < 2)
@@ -338,16 +343,11 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 	gog_renderer_push_clip_rectangle (rend, view->residual.x, view->residual.y,
 					  view->residual.w, view->residual.h);
 
-	style = gog_style_new ();
-	style->interesting_fields = GOG_STYLE_FILL | GOG_STYLE_OUTLINE;
-	style->disable_theming = GOG_STYLE_ALL;
-	style->fill.type = GOG_FILL_STYLE_PATTERN;
+	style = go_style_new ();
+	style->interesting_fields = GO_STYLE_FILL | GO_STYLE_OUTLINE;
+	style->disable_theming = GO_STYLE_ALL;
+	style->fill.type = GO_STYLE_FILL_PATTERN;
 	style->fill.pattern.pattern = GO_PATTERN_SOLID;
-	style->outline.dash_type = GO_LINE_SOLID;
-	style->outline.auto_dash = FALSE;
-	style->outline.auto_color = FALSE;
-	style->outline.width = 1.; /* seems a lower value shows grid effects */
-	style->outline.color = RGBA_BLACK;
 
 	lines = go_path_new ();
 
@@ -356,17 +356,17 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 			x0 = gog_axis_map_to_view (x_map, j);
 			x1 = gog_axis_map_to_view (x_map, j + 1);
 		} else {
-			x0 = gog_axis_map_to_view (x_map, go_data_vector_get_value (x_vec, j - 1));
-			x1 = gog_axis_map_to_view (x_map, go_data_vector_get_value (x_vec, j));
+			x0 = gog_axis_map_to_view (x_map, go_data_get_vector_value (x_vec, j - 1));
+			x1 = gog_axis_map_to_view (x_map, go_data_get_vector_value (x_vec, j));
 		}
-		
+
 		for (i = 1; i < imax; i++) {
 			if (ydiscrete) {
 				y0 = gog_axis_map_to_view (y_map, i);
 				y1 = gog_axis_map_to_view (y_map, i + 1);
 			} else {
-				y0 = gog_axis_map_to_view (y_map, go_data_vector_get_value (y_vec, i - 1));
-				y1 = gog_axis_map_to_view (y_map, go_data_vector_get_value (y_vec, i));
+				y0 = gog_axis_map_to_view (y_map, go_data_get_vector_value (y_vec, i - 1));
+				y1 = gog_axis_map_to_view (y_map, go_data_get_vector_value (y_vec, i));
 			}
 			nans = 0;
 			nan = 4;
@@ -476,7 +476,7 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 				for (k = 1; k < s; k++)
 					go_path_line_to (path, x[k], y[k]);
 				/* narrow parameter is TRUE below to avoid border effects */
-				gog_renderer_draw_shape (rend, path);
+				gog_renderer_fill_shape (rend, path);
 				go_path_clear (path);
 				gog_renderer_pop_style (rend);
 			} else {
@@ -531,10 +531,11 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 						go_path_line_to (path, xl[0], yl[0]);
 						go_path_line_to (lines, xl[0], yl[0]);
 						gog_renderer_push_style (rend, style);
-						gog_renderer_draw_shape (rend, path);
+						gog_renderer_fill_shape (rend, path);
 						go_path_clear (path);
 						gog_renderer_pop_style (rend);
 						while (k < zn) {
+
 							style->outline.color = color[k];
 							style->fill.pattern.back = color[k];
 							k++;
@@ -549,11 +550,11 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 							t = (k - zval[0]) / (zval[1] - zval[0]);
 							xl[0] = x[0] + t * (x[1] - x[0]);
 							yl[0] =y[0] + t * (y[1] - y[0]);
-							go_path_line_to (path, xl[7], yl[7]);
-							go_path_line_to (lines, xl[7], yl[7]);
+							go_path_line_to (path, xl[0], yl[0]);
+							go_path_line_to (lines, xl[0], yl[0]);
 							go_path_line_to (path, xc, yc);
 							gog_renderer_push_style (rend, style);
-							gog_renderer_draw_shape (rend, path);
+							gog_renderer_fill_shape (rend, path);
 							go_path_clear (path);
 							gog_renderer_pop_style (rend);
 						}
@@ -576,7 +577,7 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 						go_path_line_to (path, xl[4], yl[4]);
 						go_path_line_to (lines, xl[4], yl[4]);
 						gog_renderer_push_style (rend, style);
-						gog_renderer_draw_shape (rend, path);
+						gog_renderer_fill_shape (rend, path);
 						go_path_clear (path);
 						gog_renderer_pop_style (rend);
 						while (k < zn) {
@@ -598,7 +599,7 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 							go_path_line_to (lines, xl[4], yl[4]);
 							go_path_line_to (path, xc, yc);
 							gog_renderer_push_style (rend, style);
-							gog_renderer_draw_shape (rend, path);
+							gog_renderer_fill_shape (rend, path);
 							go_path_clear (path);
 							gog_renderer_pop_style (rend);
 						}
@@ -623,7 +624,7 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 						style->outline.color = color[k];
 						style->fill.pattern.back = color[k];
 						gog_renderer_push_style (rend, style);
-						gog_renderer_draw_shape (rend, path);
+						gog_renderer_fill_shape (rend, path);
 						go_path_clear (path);
 						gog_renderer_pop_style (rend);
 						k--;
@@ -645,7 +646,7 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 							style->outline.color = color[k];
 							style->fill.pattern.back = color[k];
 							gog_renderer_push_style (rend, style);
-							gog_renderer_draw_shape (rend, path);
+							gog_renderer_fill_shape (rend, path);
 							go_path_clear (path);
 							gog_renderer_pop_style (rend);
 							k--;
@@ -670,7 +671,7 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 						style->outline.color = color[k];
 						style->fill.pattern.back = color[k];
 						gog_renderer_push_style (rend, style);
-						gog_renderer_draw_shape (rend, path);
+						gog_renderer_fill_shape (rend, path);
 						go_path_clear (path);
 						gog_renderer_pop_style (rend);
 						k--;
@@ -692,7 +693,7 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 							style->outline.color = color[k];
 							style->fill.pattern.back = color[k];
 							gog_renderer_push_style (rend, style);
-							gog_renderer_draw_shape (rend, path);
+							gog_renderer_fill_shape (rend, path);
 							go_path_clear (path);
 							gog_renderer_pop_style (rend);
 							k--;
@@ -733,7 +734,7 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 							style->outline.color = color[zn];
 							style->fill.pattern.back = color[zn];
 							gog_renderer_push_style (rend, style);
-							gog_renderer_draw_shape (rend, path);
+							gog_renderer_fill_shape (rend, path);
 							go_path_clear (path);
 							if (xl[4] < 0.)
 								go_path_move_to (path, x[2], y[2]);
@@ -744,7 +745,7 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 							go_path_line_to (path, xb[2], yb[2]);
 							if (xl[4] >= 0.)
 								go_path_line_to (path, xl[4], yl[4]);
-							gog_renderer_draw_shape (rend, path);
+							gog_renderer_fill_shape (rend, path);
 							go_path_clear (path);
 							gog_renderer_pop_style (rend);
 							if (xl[2] < 0.)
@@ -759,7 +760,7 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 							style->outline.color = color[zx];
 							style->fill.pattern.back = color[zx];
 							gog_renderer_push_style (rend, style);
-							gog_renderer_draw_shape (rend, path);
+							gog_renderer_fill_shape (rend, path);
 							go_path_clear (path);
 							if (xl[6] < 0.)
 								go_path_move_to (path, x[3], y[3]);
@@ -770,19 +771,20 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 							go_path_line_to (path, xb[3], yb[3]);
 							if (xl[6] >= 0.)
 								go_path_line_to (path, xl[6], yl[6]);
-							gog_renderer_draw_shape (rend, path);
+							gog_renderer_fill_shape (rend, path);
 							go_path_clear (path);
 							gog_renderer_pop_style (rend);
 						} else {
 							if (up) {
 								/* saddle point is in the lower slice */
 								/* draw the upper slices */
-								if (xl[1] < 0.)
+								if (xl[1] < 0.) {
 									go_path_move_to (path, x[1], y[1]);
-								else {
+									xc = -1;
+								} else {
 									go_path_move_to (path, xl[1], yl[1]);
 									xc = xl[2];
-									xc = yl[2];
+									yc = yl[2];
 								}
 								t = (zx - zval[1]) / (zval[0] - zval[1]);
 								xl[1] = x[1] + t * (x[0] - x[1]);
@@ -794,19 +796,20 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 								yl[2] = y[1] + t * (y[2] - y[1]);
 								go_path_line_to (lines, xl[2], yl[2]);
 								go_path_line_to (path, xl[2], yl[2]);
-								if (xl[1] >= 0.)
+								if (xc >= 0.)
 									go_path_line_to (path, xc, yc);
 								style->outline.color = color[zx];
 								style->fill.pattern.back = color[zx];
 								gog_renderer_push_style (rend, style);
-								gog_renderer_draw_shape (rend, path);
+								gog_renderer_fill_shape (rend, path);
 								go_path_clear (path);
-								if (xl[5] < 0.)
+								if (xl[5] < 0.) {
 									go_path_move_to (path, x[3], y[3]);
-								else {
+									xc = -1;
+								} else {
 									go_path_move_to (path, xl[5], yl[5]);
 									xc = xl[6];
-									xc = yl[6];
+									yc = yl[6];
 								}
 								t = (zx - zval[3]) / (zval[2] - zval[3]);
 								xl[5] = x[3] + t * (x[2] - x[3]);
@@ -818,19 +821,20 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 								yl[6] = y[3] + t * (y[0] - y[3]);
 								go_path_line_to (lines, xl[6], yl[6]);
 								go_path_line_to (path, xl[6], yl[6]);
-								if (xl[1] >= 0.)
+								if (xc >= 0.)
 									go_path_line_to (path, xc, yc);
-								gog_renderer_draw_shape (rend, path);
+								gog_renderer_fill_shape (rend, path);
 								go_path_clear (path);
 								gog_renderer_pop_style (rend);
 							} else {
 								/* saddle point is in the upper slice */
-								if (xl[0] < 0.)
+								if (xl[0] < 0.) {
 									go_path_move_to (path, x[0], y[0]);
-								else {
+									xc = -1.;
+								} else {
 									go_path_move_to (path, xl[7], yl[7]);
 									xc = xl[0];
-									xc = yl[0];
+									yc = yl[0];
 								}
 								t = (k - zval[0]) / (zval[3] - zval[0]);
 								xl[7] = x[0] + t * (x[3] - x[0]);
@@ -842,19 +846,20 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 								yl[0] = y[0] + t * (y[1] - y[0]);
 								go_path_line_to (lines, xl[0], yl[0]);
 								go_path_line_to (path, xl[0], yl[0]);
-								if (xl[1] >= 0.)
+								if (xc >= 0.)
 									go_path_line_to (path, xc, yc);
 								style->outline.color = color[zn];
 								style->fill.pattern.back = color[zn];
 								gog_renderer_push_style (rend, style);
-								gog_renderer_draw_shape (rend, path);
+								gog_renderer_fill_shape (rend, path);
 								go_path_clear (path);
-								if (xl[4] < 0.)
+								if (xl[4] < 0.) {
 									go_path_move_to (path, x[2], y[2]);
-								else {
+									xc = -1.;
+								} else {
 									go_path_move_to (path, xl[3], yl[3]);
 									xc = xl[4];
-									xc = yl[4];
+									yc = yl[4];
 								}
 								t = (k - zval[2]) / (zval[1] - zval[2]);
 								xl[3] = x[2] + t * (x[1] - x[2]);
@@ -866,9 +871,9 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 								yl[4] = y[2] + t * (y[3] - y[2]);
 								go_path_line_to (lines, xl[4], yl[4]);
 								go_path_line_to (path, xl[4], yl[4]);
-								if (xl[1] >= 0.)
+								if (xc >= 0.)
 									go_path_line_to (path, xc, yc);
-								gog_renderer_draw_shape (rend, path);
+								gog_renderer_fill_shape (rend, path);
 								go_path_clear (path);
 								gog_renderer_pop_style (rend);
 								zn = zx;
@@ -889,7 +894,7 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 							style->outline.color = color[zn];
 							style->fill.pattern.back = color[zn];
 							gog_renderer_push_style (rend, style);
-							gog_renderer_draw_shape (rend, path);
+							gog_renderer_fill_shape (rend, path);
 							go_path_clear (path);
 							gog_renderer_pop_style (rend);
 						}
@@ -909,7 +914,7 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 						style->outline.color = color[zx];
 						style->fill.pattern.back = color[zx];
 						gog_renderer_push_style (rend, style);
-						gog_renderer_draw_shape (rend, path);
+						gog_renderer_fill_shape (rend, path);
 						go_path_clear (path);
 						gog_renderer_pop_style (rend);
 					}
@@ -985,7 +990,7 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 							}
 						}
 						s = r + 1;
-						gog_renderer_draw_shape (rend, path);
+						gog_renderer_fill_shape (rend, path);
 						go_path_clear (path);
 						gog_renderer_pop_style (rend);
 						go_path_move_to (path, x1, y1);
@@ -1000,7 +1005,9 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 						}
 					}
 					if (fabs (x0 - x1) < CONTOUR_EPSILON
-						&& fabs (y0 - y1) < CONTOUR_EPSILON)
+						&& fabs (y0 - y1) < CONTOUR_EPSILON
+						&&fabs (x0 - x[0]) > CONTOUR_EPSILON
+						&& fabs (y0 - y[0]) > CONTOUR_EPSILON)
 						continue;
 					while (k < s) {
 						go_path_line_to (path, x[k], y[k]);
@@ -1009,13 +1016,14 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 					style->outline.color = color[zmin];
 					style->fill.pattern.back = color[zmin];
 					gog_renderer_push_style (rend, style);
-					gog_renderer_draw_shape (rend, path);
+					gog_renderer_fill_shape (rend, path);
 					go_path_clear (path);
 					gog_renderer_pop_style (rend);
 				}
 			}
 		}
 	}
+
 	gog_renderer_push_style (rend, GOG_STYLED_OBJECT (series)->style);
 	gog_renderer_stroke_serie (rend, lines);
 	gog_renderer_pop_style (rend);
@@ -1035,5 +1043,4 @@ gog_contour_view_class_init (GogViewClass *view_klass)
 
 GSF_DYNAMIC_CLASS (GogContourView, gog_contour_view,
 	gog_contour_view_class_init, NULL,
-	GOG_PLOT_VIEW_TYPE)
-
+	GOG_TYPE_PLOT_VIEW)
